@@ -1,7 +1,8 @@
-context("InterOp - ImpFuncs")
+context("InterOp - imputation functions")
 
 # Set-up
-NUM_OBS <- 50
+set.seed(2020)
+NUM_OBS <- 100
 testData <- data.frame(
     x1 = rnorm(NUM_OBS, mean = 2, sd = 1),
     x2 = rnorm(NUM_OBS, mean = 2, sd = 1),
